@@ -34,12 +34,12 @@ from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import StatusStringType
 from .type_defs import (
-    DescribeTableResponseResponseTypeDef,
-    GetStatementResultResponseResponseTypeDef,
-    ListDatabasesResponseResponseTypeDef,
-    ListSchemasResponseResponseTypeDef,
-    ListStatementsResponseResponseTypeDef,
-    ListTablesResponseResponseTypeDef,
+    DescribeTableResponseTypeDef,
+    GetStatementResultResponseTypeDef,
+    ListDatabasesResponseTypeDef,
+    ListSchemasResponseTypeDef,
+    ListStatementsResponseTypeDef,
+    ListTablesResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -55,7 +55,7 @@ __all__ = (
 
 class DescribeTablePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#describetablepaginator)
     """
 
@@ -70,31 +70,31 @@ class DescribeTablePaginator(Boto3Paginator):
         SecretArn: str = None,
         Table: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeTableResponseResponseTypeDef]:
+    ) -> Iterator[DescribeTableResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#describetablepaginator)
         """
 
 
 class GetStatementResultPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#getstatementresultpaginator)
     """
 
     def paginate(
         self, *, Id: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetStatementResultResponseResponseTypeDef]:
+    ) -> Iterator[GetStatementResultResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#getstatementresultpaginator)
         """
 
 
 class ListDatabasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listdatabasespaginator)
     """
 
@@ -106,16 +106,16 @@ class ListDatabasesPaginator(Boto3Paginator):
         DbUser: str = None,
         SecretArn: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDatabasesResponseResponseTypeDef]:
+    ) -> Iterator[ListDatabasesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listdatabasespaginator)
         """
 
 
 class ListSchemasPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listschemaspaginator)
     """
 
@@ -129,16 +129,16 @@ class ListSchemasPaginator(Boto3Paginator):
         SchemaPattern: str = None,
         SecretArn: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSchemasResponseResponseTypeDef]:
+    ) -> Iterator[ListSchemasResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listschemaspaginator)
         """
 
 
 class ListStatementsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#liststatementspaginator)
     """
 
@@ -149,16 +149,16 @@ class ListStatementsPaginator(Boto3Paginator):
         StatementName: str = None,
         Status: StatusStringType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListStatementsResponseResponseTypeDef]:
+    ) -> Iterator[ListStatementsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#liststatementspaginator)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listtablespaginator)
     """
 
@@ -173,8 +173,8 @@ class ListTablesPaginator(Boto3Paginator):
         SecretArn: str = None,
         TablePattern: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTablesResponseResponseTypeDef]:
+    ) -> Iterator[ListTablesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listtablespaginator)
         """
